"""
Dictionaries module for Montreal function to hub function
SPDX - License - Identifier: LGPL - 3.0 - or -later
Copyright © 2022 Concordia CERC group
Project Coder Guille Gutierrez Guillermo.GutierrezMorote@concordia.ca
"""

import hub.helpers.constants as cte


class MontrealFunctionToHubFunction:

  def __init__(self):
    self._dictionary = {
      "Administration publique municipale et régionale": cte.MEDIUM_OFFICE,
      "Administration publique provinciale": cte.MEDIUM_OFFICE,
      "Agence de voyages ou d'expéditions": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Aiguillage et cour de triage de chemins de fer": cte.WAREHOUSE,
      "Amphithéâtre et auditorium": cte.EVENT_LOCATION,
      "Archives (incluant cinémathèquevidéothèque)": cte.EVENT_LOCATION,
      "Aréna et activités connexes (patinage sur glace)": cte.SPORTS_LOCATION,
      "Association civiquesociale et fraternelle": cte.OFFICE_AND_ADMINISTRATION,
      "Associationunion ou coop d'épargne et de prêt (inclus caisses populaires locales)": cte.OFFICE_AND_ADMINISTRATION,
      "Atelier d'artiste": cte.WAREHOUSE,
      "Atelier d'artiste ou d'artisan": cte.WAREHOUSE,
      "Atelier d'usinage": cte.WAREHOUSE,
      "Atelier de mécanicien-dentiste": cte.WAREHOUSE,
      "Auberge ou gîte touristique (Hôtel à caractère familiald'au plus 3 étages en hauteur de bâtiment)": cte.SMALL_HOTEL,
      "Autoroute": cte.WAREHOUSE,
      "Autres activités agricoles": cte.INDUSTRY,
      "Autres activités culturelles": cte.EVENT_LOCATION,
      "Autres activités d'hébergement": cte.MULTI_FAMILY_HOUSE,
      "Autres activités d'impression commerciale": cte.WAREHOUSE,
      "Autres activités de la restauration": cte.WAREHOUSE,
      "Autres activités de récupération et de triage": cte.WAREHOUSE,
      "Autres activités de vente au détail (inclus les kiosques d'autres choses que vêtements et accessoires de vêtements)": cte.STAND_ALONE_RETAIL,
      "Autres activités de vente au détail de produits de l'alimentation": cte.STAND_ALONE_RETAIL,
      "Autres activités de vente au détail de vêtements comme les accessoires": cte.STAND_ALONE_RETAIL,
      "Autres activités de vente au détail reliées aux automobilesaux embarcationsaux avions et à leurs accessoires": cte.STAND_ALONE_RETAIL,
      "Autres activités de vente en gros": cte.WAREHOUSE,
      "Autres activités minières et extraction de carrières de minerais non métalliques (sauf le pétrole)": cte.INDUSTRY,
      "Autres activités nautiques": cte.WAREHOUSE,
      "Autres activités religieuses": cte.OFFICE_AND_ADMINISTRATION,
      "Autres activités reliées au transport de matériaux par camion": cte.WAREHOUSE,
      "Autres activités reliées au transport par autobus": cte.WAREHOUSE,
      "Autres activités reliées au transport par chemin de fer": cte.WAREHOUSE,
      "Autres activités sportives (inclus centres de tir à l'arc)": cte.SPORTS_LOCATION,
      "Autres aménagements d'assemblées publiques": cte.OFFICE_AND_ADMINISTRATION,
      "Autres aménagements publics pour différentes activités": cte.OFFICE_AND_ADMINISTRATION,
      "Autres aéroports": cte.WAREHOUSE,
      "Autres bases et réserves militaires": cte.WAREHOUSE,
      "Autres centres de recherche": cte.SECONDARY_SCHOOL,
      "Autres centres de services sociaux ou bureaux de travailleurs sociaux": cte.OFFICE_AND_ADMINISTRATION,
      "Autres centres et réseaux de télévision et de radiodiffusion (système combiné)": cte.MEDIUM_OFFICE,
      "Autres entreposages": cte.WAREHOUSE,
      "Autres espaces de plancher inoccupé": cte.WAREHOUSE,
      "Autres espaces de terrain et étendues d'eau inexploités": cte.WAREHOUSE,
      "Autres expositions d'objets culturels": cte.EVENT_LOCATION,
      "Autres immeubles résidentiels": cte.MID_RISE_APARTMENT,
      "Autres industries d'appareils d'éclairage": cte.INDUSTRY,
      "Autres industries de boissons": cte.INDUSTRY,
      "Autres industries de la fabrication d'éléments de charpentes métalliques": cte.INDUSTRY,
      "Autres industries de la fonte et de l'affinage de métaux non-ferreux": cte.INDUSTRY,
      "Autres industries de la machinerie industrielle et de l'équipement industriel": cte.INDUSTRY,
      "Autres industries de pièces et d'accessoires pour véhicules automobiles": cte.INDUSTRY,
      "Autres industries de produits alimentaires": cte.INDUSTRY,
      "Autres industries de produits alimentaires à base de fruits et de légumes": cte.INDUSTRY,
      "Autres industries de produits chimiques": cte.INDUSTRY,
      "Autres industries de produits du pétrole et du charbon": cte.INDUSTRY,
      "Autres industries de produits en béton": cte.INDUSTRY,
      "Autres industries de produits en caoutchouc": cte.INDUSTRY,
      "Autres industries de produits en fil métallique": cte.INDUSTRY,
      "Autres industries de produits en plastique": cte.INDUSTRY,
      "Autres industries de produits manufacturés": cte.INDUSTRY,
      "Autres industries de produits métalliques d'ornement et d'architecture": cte.INDUSTRY,
      "Autres industries de produits métalliques divers": cte.INDUSTRY,
      "Autres industries de produits textiles": cte.INDUSTRY,
      "Autres industries de produits électriques.": cte.INDUSTRY,
      "Autres industries de vêtements coupés cousus pour femmes et filles": cte.INDUSTRY,
      "Autres industries du bois": cte.INDUSTRY,
      "Autres industries du laminagedu moulage et de l'extrusion de métaux non-ferreux": cte.INDUSTRY,
      "Autres industries du matériel de transport": cte.INDUSTRY,
      "Autres industries du matériel scientifique et professionnel": cte.INDUSTRY,
      "Autres industries du matériel électrique d'usage industriel": cte.INDUSTRY,
      "Autres industries du matériel électronique et de communication": cte.INDUSTRY,
      "Autres industries du meuble de bureau": cte.INDUSTRY,
      "Autres industries du meuble et d'articles d'ameublement": cte.INDUSTRY,
      "Autres industries du meuble résidentiel.": cte.INDUSTRY,
      "Autres industries du papier": cte.INDUSTRY,
      "Autres industries sidérurgiques": cte.INDUSTRY,
      "Autres infrastructures de transport maritime": cte.INDUSTRY,
      "Autres installations inhérentes aux ordures": cte.WAREHOUSE,
      "Autres installations pour les sports": cte.SPORTS_LOCATION,
      "Autres institutions de formation spécialisée (inclus écoles de langues de coutured'arts martiaux de combats et autres)": cte.SECONDARY_SCHOOL,
      "Autres lieux d'assemblée pour les loisirs": cte.OFFICE_AND_ADMINISTRATION,
      "Autres locaux de groupes": cte.OFFICE_AND_ADMINISTRATION,
      "Autres maisons d'institutions religieuses": cte.OFFICE_AND_ADMINISTRATION,
      "Autres maisons et locaux fraternels": cte.OFFICE_AND_ADMINISTRATION,
      "Autres maisons pour personnes retraitées": cte.OFFICE_AND_ADMINISTRATION,
      "Autres parcs": cte.WAREHOUSE,
      "Autres routes et voies publiques": cte.WAREHOUSE,
      "Autres résidences d'étudiants": cte.DORMITORY,
      "Autres résidences provisoires": cte.DORMITORY,
      "Autres services connexes aux valeurs mobilières et aux marchandises": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Autres services d'affaires": cte.MEDIUM_OFFICE,
      "Autres services d'aqueduc et d'irrigation": cte.WAREHOUSE,
      "Autres services de construction de bâtiments": cte.WAREHOUSE,
      "Autres services de génie civil (entrepreneur général)": cte.WAREHOUSE,
      "Autres services de l'automobile": cte.WAREHOUSE,
      "Autres services de location (sauf entreposage)": cte.WAREHOUSE,
      "Autres services de nettoyage": cte.WAREHOUSE,
      "Autres services de réparation et d'entretien d'articles personnels et ménagers": cte.STAND_ALONE_RETAIL,
      "Autres services de soins thérapeutiques": cte.OUT_PATIENT_HEALTH_CARE,
      "Autres services de travaux de construction spécialisés": cte.WAREHOUSE,
      "Autres services de travaux de finition de bâtiment (entrepreneur spécialisé)": cte.WAREHOUSE,
      "Autres services de télécommunications": cte.STAND_ALONE_RETAIL,
      "Autres services divers": cte.WAREHOUSE,
      "Autres services du pétrole": cte.WAREHOUSE,
      "Autres services gouvernementaux": cte.OFFICE_AND_ADMINISTRATION,
      "Autres services immobiliersfinanciers et d'assurance": cte.OFFICE_AND_ADMINISTRATION,
      "Autres services médicaux et de santé": cte.OUT_PATIENT_HEALTH_CARE,
      "Autres services personnels": cte.OUT_PATIENT_HEALTH_CARE,
      "Autres services pour animaux domestiques": cte.OUT_PATIENT_HEALTH_CARE,
      "Autres services pour le transport": cte.WAREHOUSE,
      "Autres services pour les bâtiments": cte.WAREHOUSE,
      "Autres services professionnels": cte.OFFICE_AND_ADMINISTRATION,
      "Autres services publics (infrastructure)": cte.WAREHOUSE,
      "Autres services reliés à la foresterie": cte.WAREHOUSE,
      "Autres terrains de jeux et pistes athlétiques": cte.SPORTS_LOCATION,
      "Autres transports par avion (infrastructure)": cte.WAREHOUSE,
      "Autres transports par véhicule automobile": cte.WAREHOUSE,
      "Autres transportscommunications et services publics (infrastructure)": cte.GREEN_HOUSE,
      "Autres types de production végétale": cte.GREEN_HOUSE,
      "Autres ventes au détail de marchandises en général": cte.STAND_ALONE_RETAIL,
      "Autres établissements avec service complet ou restreint": cte.STAND_ALONE_RETAIL,
      "Autres établissements de débits de boissons alcoolisées": cte.STAND_ALONE_RETAIL,
      "Aéroport et aérodrome": cte.EVENT_LOCATION,
      "Bar à crème glacée": cte.QUICK_SERVICE_RESTAURANT,
      "Bar à spectacles": cte.FULL_SERVICE_RESTAURANT,
      "Bibliothèque": cte.OFFICE_AND_ADMINISTRATION,
      "Bureau de poste": cte.OFFICE_AND_ADMINISTRATION,
      "Bâtiment incendié et inutilisable": cte.NON_HEATED,
      "C.E.G.E.P. (collège d'enseignement général et professionnel)": cte.SECONDARY_SCHOOL,
      "Centre commercial de quartier (15 à 44 magasins)": cte.STRIP_MALL,
      "Centre commercial de voisinage (14 magasins et moins)": cte.STAND_ALONE_RETAIL,
      "Centre commercial local (45 à 99 magasins)": cte.STRIP_MALL,
      "Centre commercial régional (100 à 199 magasins)": cte.STRIP_MALL,
      "Centre commercial super régional (200 magasins et plus)": cte.STRIP_MALL,
      "Centre communautaire ou de quartier (inclus Centre diocésain)": cte.OFFICE_AND_ADMINISTRATION,
      "Centre d'accueil ou établissement curatif (inclus centre de réadaptation pour handicapés physiques et mentaux)": cte.OUT_PATIENT_HEALTH_CARE,
      "Centre d'appels téléphoniques": cte.MEDIUM_OFFICE,
      "Centre d'entraide et de ressources communautaires (inclus ressources d'hébergement de meubles et d'alimentation)": cte.OUT_PATIENT_HEALTH_CARE,
      "Centre d'entreposage de produits pétroliers (pétrole brutgaz pétrole liquéfiémazout domestique et autres produits raffinés)": cte.WAREHOUSE,
      "Centre d'entreposage du gaz (avant distrib.aux consommateurs)": cte.WAREHOUSE,
      "Centre de distribution ou d'expédition de marchandises diverses": cte.WAREHOUSE,
      "Centre de recherche d'activités émergentes (inclus technologies langagières et la photonique)": cte.SECONDARY_SCHOOL,
      "Centre de santé (inclus saunas spas et bains thérapeutiques ou turcs)": cte.OUT_PATIENT_HEALTH_CARE,
      "Centre de services sociaux (C.S.S. et C.R.S.S.S.)": cte.OUT_PATIENT_HEALTH_CARE,
      "Centre de transfert ou d'entreposage de déchets dangereux": cte.WAREHOUSE,
      "Centre de tri postal": cte.WAREHOUSE,
      "Centre de vérification technique d'automobiles et d'estimation": cte.WAREHOUSE,
      "Centre local de services communautaires (C.L.S.C.)": cte.OFFICE_AND_ADMINISTRATION,
      "Centre militaire de transport et d'entreposage": cte.WAREHOUSE,
      "Centre récréatif en général (activités récréatives diversifiées pour tous groupes d'âge)": cte.EVENT_LOCATION,
      "Centre sportif multidisciplinaire (couvert).": cte.SPORTS_LOCATION,
      "Chalet ou maison de villégiature": cte.SINGLE_FAMILY_HOUSE,
      "Chemin de fer (sauf train touristiqueaiguillage et cour de triage)": cte.WAREHOUSE,
      "Cimetière": cte.WAREHOUSE,
      "Cinéma": cte.EVENT_LOCATION,
      "Clinique médicale (cabinet de médecins généralistes)": cte.OUT_PATIENT_HEALTH_CARE,
      "Commission scolaire": cte.OFFICE_AND_ADMINISTRATION,
      "Conserveriemarinagesaumurage et séchage de fruits et de légumes": cte.WAREHOUSE,
      "Construction d'immeubles pour revente": cte.WAREHOUSE,
      "Couvent": cte.EVENT_LOCATION,
      "Dépanneur (sans vente d'essence)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Entreposage de tout genre": cte.WAREHOUSE,
      "Entreposage du mobilier et d'appareils ménagersincluant les mini-entrepôts": cte.WAREHOUSE,
      "Entreposage en vrac à l'extérieur": cte.WAREHOUSE,
      "Entreposage frigorifique (sauf les armoires frigorifiques)": cte.WAREHOUSE,
      "Entreprise d'excavationde nivellementde défrichage et installation de fosses septiques": cte.WAREHOUSE,
      "Entrepôt pour le transport par camion": cte.WAREHOUSE,
      "Entretien et équipement de chemins de fer": cte.WAREHOUSE,
      "Espace de plancher inoccupé dont l'usage serait commercial autre": cte.NON_HEATED,
      "Espace de plancher inoccupé dont l'usage serait industriel": cte.NON_HEATED,
      "Espace de plancher inoccupé dont l'usage serait pour des fins culturelles": cte.NON_HEATED,
      "Espace de plancher inoccupé dont l'usage serait pour services publics": cte.NON_HEATED,
      "Espace de rangement (condo non résidentiel)": cte.NON_HEATED,
      "Espace de rangement (condo)": cte.NON_HEATED,
      "Espace de terrain non aménagé et non exploité (sauf l'exploitation non commerciale de la forêt)": cte.NON_HEATED,
      "Espace pour le séchage des boues provenant de l'usine d'épuration": cte.WAREHOUSE,
      "Fabrication de crème glacée et de desserts congelés": cte.INDUSTRY,
      "Fondations et organismes de charité": cte.OFFICE_AND_ADMINISTRATION,
      "Galerie d'art": cte.EVENT_LOCATION,
      "Garage d'autobus et équipement d'entretien": cte.WAREHOUSE,
      "Garage de stationnement pour automobiles (infrastructure)": cte.WAREHOUSE,
      "Garage de stationnement pour véhicules lourds (Infrastructure)": cte.WAREHOUSE,
      "Garage et équipement d'entretien pour le transport par camion (incluant garages municipaux)": cte.WAREHOUSE,
      "Gare d'autobus pour passagers": cte.WAREHOUSE,
      "Gare de chemins de fer": cte.WAREHOUSE,
      "Gymnase et formation athlétique": cte.SPORTS_LOCATION,
      "Hangar à avion": cte.WAREHOUSE,
      "Hôtel (incluant les hôtels-motels)": cte.SMALL_HOTEL,
      "Hôtel résidentiel": cte.SMALL_HOTEL,
      "Immeuble commercial": cte.STAND_ALONE_RETAIL,
      "Immeuble non résidentiel en construction": cte.NON_HEATED,
      "Immeuble résidentiel en construction": cte.RESIDENTIAL,
      "Immeuble à bureaux": cte.MEDIUM_OFFICE,
      "Immeuble à temps partagé («time share») Propriété ou copropriété ou groupe d'usufruitier ont chacun droit de jouissancepériodique et successif.": cte.MEDIUM_OFFICE,
      "Incinérateur": cte.INDUSTRY,
      "Industrie d'accessoires vestimentaires et d'autres vêtements": cte.INDUSTRY,
      "Industrie d'alcools destinés à la consommation (distillerie)": cte.INDUSTRY,
      "Industrie d'appareils d'éclairage (sauf ampoules et tubes)": cte.INDUSTRY,
      "Industrie d'appareils orthopédiques et chirurgicaux": cte.INDUSTRY,
      "Industrie d'armoires de placards de cuisine et de coiffeuses de salle de bains en bois": cte.INDUSTRY,
      "Industrie d'articles de maison en textile et d'articles d'hygiène en textile": cte.INDUSTRY,
      "Industrie d'articles de sport et d'athlétisme": cte.INDUSTRY,
      "Industrie d'assaisonnements et de vinaigrettes": cte.INDUSTRY,
      "Industrie d'autres produits de boulangerie et de pâtisseries": cte.INDUSTRY,
      "Industrie d'autres vêtements coupés cousus pour hommes et garçons": cte.INDUSTRY,
      "Industrie d'engrais chimique et d'engrais composé": cte.INDUSTRY,
      "Industrie d'enseignes au néon (excluant les enseignes en bois) éclairage interne": cte.INDUSTRY,
      "Industrie d'équipements de télécommunication": cte.INDUSTRY,
      "Industrie de bas et de chaussettes": cte.INDUSTRY,
      "Industrie de boissons gazeuses": cte.INDUSTRY,
      "Industrie de boîtes en carton ondulé et en carton compact": cte.INDUSTRY,
      "Industrie de boîtes pliantes et rigides": cte.INDUSTRY,
      "Industrie de carrosseries de véhicules automobiles": cte.INDUSTRY,
      "Industrie de chaudièresd'échangeurs de chaleur et de plaques métalliques": cte.INDUSTRY,
      "Industrie de contenants en plastique (sauf en mousse)": cte.INDUSTRY,
      "Industrie de contreplaqués en bois": cte.INDUSTRY,
      "Industrie de fabrication de gaz industriel": cte.INDUSTRY,
      "Industrie de fils et de câbles électriques": cte.INDUSTRY,
      "Industrie de filés et de tissus tissés (coton)": cte.INDUSTRY,
      "Industrie de garnitures et de raccords de plomberie en métal": cte.INDUSTRY,
      "Industrie de jouets et de jeux": cte.INDUSTRY,
      "Industrie de l'abattage et du conditionnement de la viande (sauf la volaille et le petit gibier)": cte.INDUSTRY,
      "Industrie de l'abattage et du conditionnement de la volaille et du petit gibier": cte.INDUSTRY,
      "Industrie de l'impression de formulaires commerciaux": cte.INDUSTRY,
      "Industrie de l'équipement de manutention": cte.INDUSTRY,
      "Industrie de l'étirage de l'extrusion et alliage de l'aluminiumfabriqué à partir d'aluminium acheté": cte.INDUSTRY,
      "Industrie de la bijouterie et de l'orfèvrerie (sauf l'affinage secondaire de métaux précieux)": cte.INDUSTRY,
      "Industrie de la bière": cte.INDUSTRY,
      "Industrie de la chaussure": cte.INDUSTRY,
      "Industrie de la confection à forfait de vêtements pour femmes et filles": cte.INDUSTRY,
      "Industrie de la construction et de la réparation de navires": cte.INDUSTRY,
      "Industrie de la fabrication de supports d'enregistrement de la reproduction du son et des instruments de musique": cte.INDUSTRY,
      "Industrie de la glace": cte.INDUSTRY,
      "Industrie de la machinerie pour la construction et du matériel d'entretien": cte.INDUSTRY,
      "Industrie de la préparation et du conditionnement de poissons et de fruits de mer": cte.INDUSTRY,
      "Industrie de la quincaillerie de base": cte.INDUSTRY,
      "Industrie de la transformation de la viande et de la fonte des graisses animales": cte.INDUSTRY,
      "Industrie de la tôlerie pour ventilation": cte.INDUSTRY,
      "Industrie de lampes électriques (ampoules et tubes)": cte.INDUSTRY,
      "Industrie de moteurs et de pièces de moteurs de véhicules automobiles": cte.INDUSTRY,
      "Industrie de mélange de farine et de pâte": cte.INDUSTRY,
      "Industrie de peinturede teinture et de vernis": cte.INDUSTRY,
      "Industrie de pellicules et de feuilles non renforcées en plastique": cte.INDUSTRY,
      "Industrie de pièces en plastique pour véhicules automobiles": cte.INDUSTRY,
      "Industrie de pièces et de composantes électroniques": cte.INDUSTRY,
      "Industrie de pneus et de chambres à air": cte.INDUSTRY,
      "Industrie de portes et de fenêtres en métal": cte.INDUSTRY,
      "Industrie de portes et fenêtres en plastique": cte.INDUSTRY,
      "Industrie de produits chimiques inorganiques d'usage industriel": cte.INDUSTRY,
      "Industrie de produits d'architecture en plastique": cte.INDUSTRY,
      "Industrie de produits de boulangerie commerciale de produits de boulangerie congelés et de pâtisseries": cte.INDUSTRY,
      "Industrie de produits de toilette": cte.INDUSTRY,
      "Industrie de produits en pierre": cte.INDUSTRY,
      "Industrie de produits en plastique stratifié sous pression ou renforcé": cte.INDUSTRY,
      "Industrie de produits en verre fabriqué à partir de verre acheté": cte.INDUSTRY,
      "Industrie de produits pharmaceutiques et de médicaments": cte.INDUSTRY,
      "Industrie de produits pétrochimiques": cte.INDUSTRY,
      "Industrie de produits pétroliers raffinés (sauf les huiles de graissage et les graisses lubrifiantes)": cte.INDUSTRY,
      "Industrie de pâtes alimentaires sèches": cte.INDUSTRY,
      "Industrie de récipients et de boîtes en métal": cte.INDUSTRY,
      "Industrie de résines synthétiques et de caoutchouc synthétique": cte.INDUSTRY,
      "Industrie de sacs et de poches en matière textile": cte.INDUSTRY,
      "Industrie de sacs et de sachets en plastique": cte.INDUSTRY,
      "Industrie de savons et de détachants pour le nettoyage": cte.INDUSTRY,
      "Industrie de sommiers et de matelas": cte.INDUSTRY,
      "Industrie de soupapes en métal": cte.INDUSTRY,
      "Industrie de tapis carpettes et moquettes": cte.INDUSTRY,
      "Industrie de tous les autres produits divers en bois": cte.INDUSTRY,
      "Industrie de tous les autres produits en papier transformé (sauf pour le bureau)": cte.INDUSTRY,
      "Industrie de ventilateursde soufflantes et de purificateurs d'air industriels et commerciaux": cte.INDUSTRY,
      "Industrie de vêtements de sport pour femmes et filles": cte.INDUSTRY,
      "Industrie de vêtements professionnels coupés cousus": cte.INDUSTRY,
      "Industrie des pièces et accessoires d'aéronefs (incluant avions et hélicoptères)": cte.INDUSTRY,
      "Industrie du béton préparé": cte.INDUSTRY,
      "Industrie du cannabis": cte.INDUSTRY,
      "Industrie du ciment": cte.INDUSTRY,
      "Industrie du clichagede la composition de la reliure et de la lithographie": cte.INDUSTRY,
      "Industrie du fromage": cte.INDUSTRY,
      "Industrie du lait de consommation": cte.INDUSTRY,
      "Industrie du laminagede l'étirage et de l'extrusion du cuivre et de ses alliages": cte.INDUSTRY,
      "Industrie du matériel de chauffage et du matériel de réfrigération commerciale": cte.INDUSTRY,
      "Industrie du matériel de transport": cte.INDUSTRY,
      "Industrie du matériel ferroviaire roulant": cte.INDUSTRY,
      "Industrie du matériel électrique de communication et de protection": cte.INDUSTRY,
      "Industrie du meuble de maison en bois": cte.INDUSTRY,
      "Industrie du meuble et d'articles d'ameublement pour hôtelsrestaurants et institutions": cte.INDUSTRY,
      "Industrie du pain": cte.INDUSTRY,
      "Industrie du revêtement métallique sur commande": cte.INDUSTRY,
      "Industrie du sucre de canne et de betterave à sucre": cte.INDUSTRY,
      "Industrie du thé et du café": cte.INDUSTRY,
      "Industries des appareils d'aéronefs (incluant avions et hélicoptères)": cte.INDUSTRY,
      "Installation d'équipements de réfrigération commerciale": cte.WAREHOUSE,
      "Installation portuaire en général": cte.WAREHOUSE,
      "Jardin botanique": cte.WAREHOUSE,
      "Ligne de l'oléoduc": cte.WAREHOUSE,
      "Local pour les associations fraternelles": cte.EVENT_LOCATION,
      "Logement": cte.RESIDENTIAL,
      "Logement vacant dans un bâtiment comportant plusieurs logements ou autres locaux": cte.RESIDENTIAL,
      "Loisir et autres activités culturelles": cte.HALL,
      "Maison d'agents de courtiers et de services d'administration des biens-fonds": cte.MEDIUM_OFFICE,
      "Maison d'étudiants (collège et université)": cte.DORMITORY,
      "Maison de chambres et pension": cte.DORMITORY,
      "Maison de chambres pour personnes ayant une déficience intellectuelle": cte.DORMITORY,
      "Maison de courtiers et de négociants de marchandises": cte.MEDIUM_OFFICE,
      "Maison de réhabilitation": cte.HOSPITAL,
      "Maison des jeunes": cte.HALL,
      "Maison pour personnes en difficulté (séjours périodes limitées)": cte.HOSPITAL,
      "Maison pour personnes retraitées autonomes": cte.DORMITORY,
      "Maison pour personnes retraitées non autonomes (inclus les CHLSD)": cte.DORMITORY,
      "Marché public": cte.STRIP_MALL,
      "Meunerie et minoterie": cte.MEDIUM_OFFICE,
      "Monastère": cte.DORMITORY,
      "Monument et site historique": cte.EVENT_LOCATION,
      "Motel": cte.SMALL_HOTEL,
      "Musée": cte.EVENT_LOCATION,
      "Organisme international et autres organismes extraterritoriaux": cte.MEDIUM_OFFICE,
      "Parc d'amusement (extérieur)": cte.NON_HEATED,
      "Parc de maisons mobiles (fonds de terre seulement)": cte.NON_HEATED,
      "Parc pour la récréation en général": cte.NON_HEATED,
      "Parc à caractère récréatif et ornemental": cte.NON_HEATED,
      "Passage": cte.NON_HEATED,
      "Piscine extérieure et activités connexes": cte.NON_HEATED,
      "Piscine intérieure et activités connexes": cte.SPORTS_LOCATION,
      "Pose et réparation de parement métalliques et autres (entrepreneur spécialisé)": cte.WAREHOUSE,
      "Poste et bureau de douanes": cte.OFFICE_AND_ADMINISTRATION,
      "Pouponnière ou garderie de nuit": cte.HOSPITAL,
      "Presbytère": cte.OFFICE_AND_ADMINISTRATION,
      "Prison provinciale": cte.DORMITORY,
      "Protection contre l'incendie et activités connexes": cte.WAREHOUSE,
      "Raffinerie de pétrole": cte.INDUSTRY,
      "Restaurant et établissement avec service complet (avec terrasse) - Établissements avec permis alcool inclus pub café et brasserie": cte.FULL_SERVICE_RESTAURANT,
      "Restaurant et établissement avec service complet (sans terrasse) -Établissements avec permis alcoolinclus pub café et brasserie": cte.FULL_SERVICE_RESTAURANT,
      "Restaurant et établissement avec service restreint ( commande au comptoir ou par téléphone)": cte.QUICK_SERVICE_RESTAURANT,
      "Restaurant et établissement offrant des repas à libre-service (cafétéria cantine)": cte.QUICK_SERVICE_RESTAURANT,
      "Rue et avenue pour l'accès local": cte.NON_HEATED,
      "Ruelle": cte.NON_HEATED,
      "Récupération et triage de matières polluantes et toxiques": cte.WAREHOUSE,
      "Récupération et triage de métaux": cte.WAREHOUSE,
      "Réparation et entretien des avions": cte.WAREHOUSE,
      "Réserve pour la protection de la faune": cte.NON_HEATED,
      "Réservoir d'eau (installation d'emmagasinage de l'eau par retenue et réservoirs)": cte.NON_HEATED,
      "Résidence de tourismeappartement maison ou chalet (meublé et équipé pour repas)": cte.SMALL_HOTEL,
      "Salle d'exposition": cte.EVENT_LOCATION,
      "Salle et terrain de squash de racquetball et de tennis": cte.SPORTS_LOCATION,
      "Salle ou salon de quilles": cte.NON_HEATED,
      "Salon de beauté (maquillagemanucureetc..)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Salon de coiffure": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Salon funéraire": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Service bancaire (dépôts et prêtsincluant banque à charte)": cte.OFFICE_AND_ADMINISTRATION,
      "Service d'ambulance": cte.WAREHOUSE,
      "Service d'architecture": cte.OFFICE_AND_ADMINISTRATION,
      "Service d'assainissement de l'environnement": cte.WAREHOUSE,
      "Service d'emballage et de protection de marchandises": cte.WAREHOUSE,
      "Service d'envoi de marchandises": cte.WAREHOUSE,
      "Service d'hébergement des données (sites Web diffusion audio et vidéo en continu services d'application)": cte.WAREHOUSE,
      "Service d'hôpital (inclus hôpitaux psychiatriques)": cte.HOSPITAL,
      "Service d'optométrie": cte.OUT_PATIENT_HEALTH_CARE,
      "Service de buanderie de nettoyage à sec et de teinture (sauf les tapis)": cte.WAREHOUSE,
      "Service de comptabilitéde vérification et de tenue de livre": cte.OFFICE_AND_ADMINISTRATION,
      "Service de construction de routesde rues et de pontsde trottoirs et de pistes (entrepreneur général)": cte.WAREHOUSE,
      "Service de construction non résidentiellecommerciale et institutionnelle (entrepreneur général)": cte.WAREHOUSE,
      "Service de construction non résidentielleindustrielle (entrepreneur général)": cte.WAREHOUSE,
      "Service de construction résidentielle (entrepreneur)": cte.WAREHOUSE,
      "Service de débosselage et de peinture d'automobiles": cte.WAREHOUSE,
      "Service de garderie (prématernelle moins de 50 % de poupons)": cte.PRIMARY_SCHOOL,
      "Service de génie": cte.OFFICE_AND_ADMINISTRATION,
      "Service de holding et d'investissement et de fiducie": cte.OFFICE_AND_ADMINISTRATION,
      "Service de laboratoire dentaire": cte.OUT_PATIENT_HEALTH_CARE,
      "Service de laboratoire médical": cte.OUT_PATIENT_HEALTH_CARE,
      "Service de lavage d'automobiles": cte.WAREHOUSE,
      "Service de limousine": cte.WAREHOUSE,
      "Service de lingerie et de buanderie industrielle": cte.WAREHOUSE,
      "Service de location d'automobiles": cte.WAREHOUSE,
      "Service de location d'outils ou d'équipements": cte.WAREHOUSE,
      "Service de location d'équipements": cte.WAREHOUSE,
      "Service de location de boites postales (sauf le publipostage) et centre de courrier privé": cte.OFFICE_AND_ADMINISTRATION,
      "Service de location de camions de remorques utilitaires et de véhicules de plaisance": cte.WAREHOUSE,
      "Service de maçonnerie (entrepreneur spécialisé)": cte.INDUSTRY,
      "Service de messagers": cte.MEDIUM_OFFICE,
      "Service de notaires": cte.MEDIUM_OFFICE,
      "Service de paysagement ou de déneigement": cte.WAREHOUSE,
      "Service de petite menuiserie et de finition (entrepreneur spécialisé)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Service de plomberie de chauffagede climatisation et de ventilation (entrepreneur spécialisé)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Service de police fédérale et activités connexes": cte.OFFICE_AND_ADMINISTRATION,
      "Service de police municipale et activités connexes": cte.OFFICE_AND_ADMINISTRATION,
      "Service de pose de portesde fenêtres et de panneaux de verre": cte.WAREHOUSE,
      "Service de publicité en général": cte.MEDIUM_OFFICE,
      "Service de recherche de développement et d'essais": cte.SECONDARY_SCHOOL,
      "Service de remplacement de pièces et d'accessoires d'automobiles (amortisseurs silencieux toits ouvrants glacespare-brises...)": cte.WAREHOUSE,
      "Service de revêtement en asphalte et en bitume": cte.WAREHOUSE,
      "Service de réparation d'automobiles (garage) sans pompes à essence(5531)": cte.WAREHOUSE,
      "Service de réparation d'autres véhicules légers": cte.WAREHOUSE,
      "Service de réparation de véhicules légers motorisés (motocyclettemotoneige véhicule tout terrain)": cte.WAREHOUSE,
      "Service de réparation et d'entretien de machines et de matériel d'usage commercial et industriel": cte.WAREHOUSE,
      "Service de réparation et d'entretien de matériel informatique": cte.COMMERCIAL,
      "Service de réparation et d'entretien de systèmes de plomberieschauffageventilation et climatisation.(entrepreneur spécialisé)": cte.WAREHOUSE,
      "Service de réparation et d'entretien de véhicules lourds": cte.WAREHOUSE,
      "Service de réparation et de rembourrage de meubles": cte.WAREHOUSE,
      "Service de soudure": cte.WAREHOUSE,
      "Service de toilettage pour animaux domestiques": cte.OUT_PATIENT_HEALTH_CARE,
      "Service de traitement pour automobiles (antirouilleetc.)": cte.WAREHOUSE,
      "Service de travaux d'électricité et installation de câblage (entrepreneur spécialisé)": cte.WAREHOUSE,
      "Service de travaux de toiture (entrepreneur spécialisé)": cte.WAREHOUSE,
      "Service de télécommunication sans fil (appareil mobile sauf par Internet)": cte.WAREHOUSE,
      "Service de vétérinaires (animaux domestiques)": cte.OUT_PATIENT_HEALTH_CARE,
      "Service de vétérinaires et d'hôpital pour animaux de ferme": cte.OUT_PATIENT_HEALTH_CARE,
      "Service dentaire (inclus chirurgie et hygiène)": cte.OUT_PATIENT_HEALTH_CARE,
      "Service en santé mentale (cabinet) (comprend tous services professionnelspsychiatre psychologuepsychanalyste)": cte.OUT_PATIENT_HEALTH_CARE,
      "Service en travaux de fondation et de structures en béton (entrepreneur spécialisé)": cte.WAREHOUSE,
      "Service informatique (location ou utilisation partagée services auxiliaires programmation planification et analyse de système)": cte.MEDIUM_OFFICE,
      "Service médical (cabinet de médecins et chirurgiens spécialisés)": cte.OUT_PATIENT_HEALTH_CARE,
      "Service photographique (incluant les services commerciaux)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Service pour l'entretien ménager": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Service éducationnel et de recherche scientifique": cte.SECONDARY_SCHOOL,
      "Services spécialisés reliés à l'activité bancaire": cte.OFFICE_AND_ADMINISTRATION,
      "Stade": cte.SPORTS_LOCATION,
      "Station de contrôle de la pression de l'eau": cte.WAREHOUSE,
      "Station de contrôle de la pression des eaux usées": cte.WAREHOUSE,
      "Station de métro": cte.WAREHOUSE,
      "Station libre-serviceou avec service et dépanneur sans réparation de véhicules automobiles": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Station libre-serviceou avec service sans réparation de véhicules automobiles": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Station-service avec réparation de véhicules automobiles": cte.WAREHOUSE,
      "Stationnement extérieur (condo non résidentiel)": cte.NON_HEATED,
      "Stationnement extérieur (condo)": cte.NON_HEATED,
      "Stationnement intérieur ( condo non résidentiel)": cte.WAREHOUSE,
      "Stationnement intérieur (condo)": cte.WAREHOUSE,
      "Studio d'enregistrement du son (disque cassette et disque compact)": cte.MEDIUM_OFFICE,
      "Studio de production de filmsde vidéos ou de publicités (ne comprends pas le laboratoire de production)": cte.MEDIUM_OFFICE,
      "Studio de télévision (sans public)": cte.MEDIUM_OFFICE,
      "Syndicat et organisation similaire": cte.MEDIUM_OFFICE,
      "Terminus maritime (passagers) incluant les gares de traversiers": cte.WAREHOUSE,
      "Terrain de golf (avec chalet et autres aménagements sportifs)": cte.NON_HEATED,
      "Terrain de sport (jeux et pistes pour compétitions et sportgradins)": cte.NON_HEATED,
      "Terrain de stationnement pour automobiles": cte.WAREHOUSE,
      "Terrains de stationnement pour véhicules lourds": cte.WAREHOUSE,
      "Théâtre": cte.EVENT_LOCATION,
      "Tour de relais (micro-ondes)": cte.NON_HEATED,
      "Tous les autres services d'information": cte.NON_HEATED,
      "Transport et gestion d'électricité en bloc": cte.NON_HEATED,
      "Transport et gestion du gaz par canalisation": cte.NON_HEATED,
      "Université": cte.SECONDARY_SCHOOL,
      "Usine de traitement des eaux (filtration)": cte.INDUSTRY,
      "Usine de traitement des eaux usées (épuration)": cte.INDUSTRY,
      "Vente au détail (fleuriste)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail d'accessoires pour femmes": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail d'animaux de maison (animalerie)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail d'antiquités (sauf le marché aux puces)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail d'appareils orthopédiques et articles spécialisés de santé": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail d'articles de sport": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail d'articles d'accessoires d'aménagement paysager et de jardin": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail d'instruments et de matériel médical": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail d'équipements de ferme": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail d'équipements de plomberie de chauffagede ventilationde climatisation et de foyer": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail d'équipements et d'accessoires de chasse et pêche": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de bicyclettes": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de boissons alcoolisées": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de chaussures": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de fruits et de légumes": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Vente au détail de la viande": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Vente au détail de livres et de papeterie": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de marchandises en général (sauf les marchés aux puces)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de matériaux de construction": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de matériaux de construction (cour à bois)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de matériel électrique": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de meubles": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de motocyclettes de motoneiges et de leurs accessoires": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de médicaments et d'articles divers (pharmacie)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de peinturede verre et de papier tenture": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de piscinesde spas et leurs accessoires": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de pièces de véhicules automobiles et d'accessoires usagés": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de pneus de batteries et d'accessoires": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de produits d'épicerie (avec boucherie)": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Vente au détail de produits d'épicerie (sans boucherie)": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Vente au détail de produits de la boulangerie et de la pâtisserie (manufacturés sur place en totalité ou non)": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Vente au détail de quincaillerie": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de radiosde téléviseurssystèmes de son et appareils électroniques": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de revêtements de planchers et de murs (bois franc plancher flottant carreaux céramiques tapisserie)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de serruresde clés et d'accessoires": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de véhicules automobiles neufs et usagés": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de véhicules automobiles usagés seulement": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de vêtement prêt-à-porter pour femmes": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de vêtements et d'accessoires pour hommes": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de vêtements et d'articles usagésfriperies (sauf le marché aux puces)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de vêtements unisexes": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail du cafédu théd'épices et d'aromates": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Vente au détailclubs de gros et hypermarchés (entrepôt-club)": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Vente au détailfournitures pour la maison et l'auto": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détailmagasin à rayons": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente en gros d'ameublements de matériels de bureau et de magasin": cte.STRIP_MALL,
      "Vente en gros d'appareils et d'équipements de plomberie et de chauffage": cte.STRIP_MALL,
      "Vente en gros d'appareils et d'équipements électriques de fils et de matériel électronique de construction": cte.STRIP_MALL,
      "Vente en gros d'appareils électriquesde téléviseurs et de radios": cte.STRIP_MALL,
      "Vente en gros d'automobiles et autres véhicules automobiles neufs ou d'occasions incluent VR)": cte.STRIP_MALL,
      "Vente en gros d'autres appareils ou matériels électriques et électroniques": cte.STRIP_MALL,
      "Vente en gros d'autres médicaments de produits chimiques et de produits connexes": cte.STRIP_MALL,
      "Vente en gros d'autres pièces d'équipement ou de machinerie (incluant machinerie lourde)": cte.STRIP_MALL,
      "Vente en gros d'autres produits reliés à l'épicerie": cte.STRIP_MALL,
      "Vente en gros d'équipements et de pièces de machinerie commercialeindustrielle ou agricole (incluant machinerie lourde)": cte.STRIP_MALL,
      "Vente en gros d'équipements et de pièces pour la réfrigération ventilation la climatisation et le chauffage (système combiné)": cte.STRIP_MALL,
      "Vente en gros d'équipements et de pièces pour les entreprises de services": cte.STRIP_MALL,
      "Vente en gros de bois et de matériaux de construction": cte.STRIP_MALL,
      "Vente en gros de chaussures": cte.STRIP_MALL,
      "Vente en gros de fruits et de légumes frais": cte.STRIP_MALL,
      "Vente en gros de médicaments et de produits médicamenteux": cte.STRIP_MALL,
      "Vente en gros de pièces et d'accessoires neufs pour véhicules automobiles": cte.STRIP_MALL,
      "Vente en gros de pièces et d'équipements électroniques": cte.STRIP_MALL,
      "Vente en gros de pneus et de chambres à air": cte.STRIP_MALL,
      "Vente en gros de poissons et de fruits de mer": cte.STRIP_MALL,
      "Vente en gros de produits de beauté": cte.STRIP_MALL,
      "Vente en gros de produits de boulangerie et de pâtisserie": cte.STRIP_MALL,
      "Vente en gros de produits laitiers": cte.STRIP_MALL,
      "Vente en gros de quincaillerie": cte.STRIP_MALL,
      "Vente en gros de tissus et de textiles": cte.STRIP_MALL,
      "Vente en gros de viandes et de produits de la viande": cte.STRIP_MALL,
      "Vente en gros de vêtements de lingerie de bas et d'accessoires": cte.STRIP_MALL,
      "Vente en gros pour l'épicerie en général": cte.STRIP_MALL,
      "École commerciale et de secrétariat (non intégrée aux polyvalentes)": cte.SECONDARY_SCHOOL,
      "École de beaux-arts et de musique (exclus arts publicitaires arts graphiques et photographie publicitaire)": cte.SECONDARY_SCHOOL,
      "École de danse": cte.SECONDARY_SCHOOL,
      "École de métiers (non intégrée aux polyvalentes)": cte.SECONDARY_SCHOOL,
      "École maternelle": cte.SECONDARY_SCHOOL,
      "École polyvalente": cte.SECONDARY_SCHOOL,
      "École secondaire": cte.SECONDARY_SCHOOL,
      "École à caractère familial (exploité par une personne physique dans sa résidence moins de 15 élèves)": cte.SECONDARY_SCHOOL,
      "École élémentaire": cte.SECONDARY_SCHOOL,
      "École élémentaire et secondaire": cte.SECONDARY_SCHOOL,
      "Église synagogue mosquée et temple": cte.EVENT_LOCATION,
      "Établissement avec salle de réception ou de banquet": cte.FULL_SERVICE_RESTAURANT,
      "Établissement avec service de boissons alcoolisées (Bar)": cte.QUICK_SERVICE_RESTAURANT,
      "Établissement dont l'activité principale est la danse (discothèque avec service alcool boite de nuit) sans alcool code 7397": cte.QUICK_SERVICE_RESTAURANT,
      "Mausolée": cte.NON_HEATED,
      "Auberge ou gîte touristique (Hôtel à caractère familial, d'au plus 3 étages en hauteur de bâtiment)": cte.HOTEL,
      "Service de garderie (prématernelle, moins de 50 % de poupons)": cte.PRIMARY_SCHOOL,
      "Église, synagogue, mosquée et temple": cte.CONVENTION_CENTER,

      "Station libre-service, ou avec service et dépanneur sans réparation de véhicules automobiles": cte.WAREHOUSE,
      "Service de buanderie, de nettoyage à sec et de teinture (sauf les tapis)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Service bancaire (dépôts et prêts, incluant banque à charte)": cte.COMMERCIAL,
      "Restaurant et établissement avec service complet (avec terrasse) - Établissements avec permis alcool, inclus pub,café et brasserie": cte.FULL_SERVICE_RESTAURANT,
      "Restaurant et établissement avec service complet (sans terrasse) -Établissements avec permis alcool, inclus pub,café et brasserie": cte.FULL_SERVICE_RESTAURANT,
      "Autres services immobiliers, financiers et d'assurance": cte.COMMERCIAL,
      "Résidence de tourisme, appartement, maison ou chalet (meublé et équipé pour repas)": cte.RESIDENTIAL,
      "Salon de beauté (maquillage, manucure, etc..)": cte.COMMERCIAL,
      "Service de buanderie et de nettoyage à sec (libre-service)": cte.COMMERCIAL,
      "Association civique, sociale et fraternelle": cte.COMMERCIAL,
      "Vente en gros d'automobiles et autres véhicules automobiles neufs ou d'occasions, incluent VR)": cte.WAREHOUSE,
      "Autres services de soutien aux entreprises": cte.COMMERCIAL,
      "Vente au détail de vêtements pour toute la famille": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de bijoux": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Service d'avocats": cte.MEDIUM_OFFICE,
      "Service informatique (location ou utilisation partagée, services auxiliaires programmation planification et analyse de système)": cte.MEDIUM_OFFICE,
      "Centre d'entraide et de ressources communautaires (inclus ressources d'hébergement, de meubles et d'alimentation)": cte.COMMERCIAL,
      "Service de comptabilité, de vérification et de tenue de livre": cte.MEDIUM_OFFICE,
      "Autres transports, communications et services publics (infrastructure)": cte.WAREHOUSE,
      "Autres institutions de formation spécialisée (inclus écoles de langues, de couture, d'arts martiaux, de combats et autres)": cte.SECONDARY_SCHOOL,
      "Chemin de fer (sauf train touristique, aiguillage et cour de triage)": cte.WAREHOUSE,
      "Service d'agence de placement": cte.COMMERCIAL,
      "Espace de plancher inoccupé dont l'usage serait la vente au détail": cte.NON_HEATED,
      "Industrie de produits en plastique stratifié, sous pression ou renforcé": cte.INDUSTRY,
      "Studio de production de films, de vidéos ou de publicités (ne comprends pas le laboratoire de production)": cte.MOTION_PICTURE_THEATRE,
      "Industrie de la fabrication de supports d'enregistrement, de la reproduction du son et des instruments de musique": cte.INDUSTRY,
      "Vente au détail du café, du thé, d'épices et d'aromates": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Station libre-service, ou avec service sans réparation de véhicules automobiles": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de produits de la boulangerie et de la pâtisserie (non manufacturés sur place)": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Vente au détail de serrures, de clés et d'accessoires": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Autres activités de vente au détail de vêtements, comme les accessoires": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente en gros d'équipements et de pièces pour la réfrigération, ventilation, la climatisation et le chauffage (système combiné)": cte.WAREHOUSE,
      "Service de réparation de véhicules légers motorisés (motocyclette, motoneige, véhicule tout terrain)": cte.WAREHOUSE,
      "Service de location de camions, de remorques utilitaires et de véhicules de plaisance": cte.WAREHOUSE,
      "Vente au détail d'autres articles de ferme": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Salon d'esthétique (épilation, traitement de la peau)": cte.COMMERCIAL,
      "Service de location de films, de jeux vidéos et de matériel audiovisuel": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Vente en gros de vêtements, de lingerie, de bas et d'accessoires": cte.WAREHOUSE,
      "Service d'entretien de chaussures et d'articles de cuir (cordonnerie)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de lingerie pour enfants": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail, magasin à rayons": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de vêtements et d'articles usagés, friperies (sauf le marché aux puces)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Entreposage du mobilier et d'appareils ménagers, incluant les mini-entrepôts": cte.WAREHOUSE,
      "Service de construction non résidentielle, industrielle (entrepreneur général)": cte.WAREHOUSE,
      "Immeuble à temps partagé («time share») Propriété ou copropriété ou groupe d'usufruitier ont chacun droit de jouissance, périodique et successif.": cte.COMMERCIAL,
      "Autres activités récréatives": cte.EVENT_LOCATION,
      "Industrie de produits de boulangerie commerciale, de produits de boulangerie congelés et de pâtisseries": cte.INDUSTRY,
      "Studio d'enregistrement du son (disque, cassette et disque compact)": cte.COMMERCIAL,
      "Autres services de soins paramédicaux": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Studio de radiodiffusion (sans public)": cte.COMMERCIAL,
      "Autres présentations d'objets ou d'animaux": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Autres étendues d'eau": cte.WAREHOUSE,
      "Maison d'agents, de courtiers et de services d'administration des biens-fonds": cte.MEDIUM_OFFICE,
      "Industrie de l'édition du livre": cte.INDUSTRY,
      "Vente au détail ou location d'articles,d'accessoires de scène et de costumes": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "École de beaux-arts et de musique (exclus arts publicitaires, arts graphiques et photographie publicitaire)": cte.SECONDARY_SCHOOL,
      "Vente au détail de peinture, de verre et de papier tenture": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Agence et courtier d'assurances": cte.MEDIUM_OFFICE,
      "Centre de santé (inclus saunas, spas et bains thérapeutiques ou turcs)": cte.HEALTH_CARE,
      "Établissement dont l'activité principale est la danse (discothèque avec service alcool, boite de nuit) sans alcool code 7397": cte.QUICK_SERVICE_RESTAURANT,
      "Vente au détail de pneus, de batteries et d'accessoires": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Salle et terrain de squash, de racquetball et de tennis": cte.WAREHOUSE,
      "Service de télécommunication sans fil (appareil mobile, sauf par Internet)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Centre de recherche en science physique et chimique (inclus science optique)": cte.UNIVERSITY,
      "Association, union ou coop d'épargne et de prêt (inclus caisses populaires locales)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Industrie du meuble et d'articles d'ameublement pour hôtels, restaurants et institutions": cte.INDUSTRY,
      "Service d'affichage à l'extérieur": cte.NON_HEATED,
      "Service de traitement pour automobiles (antirouille, etc.)": cte.INDUSTRY,
      "Vente au détail de revêtements de planchers et de murs (bois franc, plancher flottant, carreaux céramiques, tapisserie)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de livres et de journaux": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Autres industries du laminage, du moulage et de l'extrusion de métaux non-ferreux": cte.INDUSTRY,
      "Vente au détail d'appareils ménagers": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Service de plomberie, de chauffage, de climatisation et de ventilation (entrepreneur spécialisé)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de radios, de téléviseurs, systèmes de son et appareils électroniques": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail, clubs de gros et hypermarchés (entrepôt-club)": cte.STRIP_MALL,
      "Conserverie, marinage, saumurage et séchage de fruits et de légumes": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Industrie de l'étirage, de l'extrusion et alliage de l'aluminium, fabriqué à partir d'aluminium acheté": cte.INDUSTRY,
      "Restaurant et établissement offrant des repas à libre-service (cafétéria, cantine)": cte.QUICK_SERVICE_RESTAURANT,
      "Pressage de vêtements": cte.COMMERCIAL,
      "Vente au détail d'articles, d'accessoires d'aménagement paysager et de jardin": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Planétarium": cte.MUSEUM,
      "Industrie de ventilateurs, de soufflantes et de purificateurs d'air industriels et commerciaux": cte.INDUSTRY,
      "Service de pose de portes, de fenêtres et de panneaux de verre": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Association de personnes exerçant une même profession ou une même activité": cte.MEDIUM_OFFICE,
      "Service de remplacement de pièces et d'accessoires d'automobiles (amortisseurs, silencieux,toits ouvrants, glaces, pare-brises...)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Service d'hébergement des données (sites Web, diffusion audio et vidéo en continu, services d'application)": cte.DATACENTER,
      "Vente au détail de produits naturels et aliments de régime": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Autres activités de vente au détail reliées aux automobiles, aux embarcations, aux avions et à leurs accessoires": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Autres lieux d'amusement": cte.EVENT_LOCATION,
      "Vente en gros d'appareils et d'équipements électriques, de fils et de matériel électronique de construction": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Industrie de peinture, de teinture et de vernis": cte.INDUSTRY,
      "Autres industries de l'impression et de l'édition (combinées)": cte.INDUSTRY,
      "Vente en gros d'équipements et de pièces de machinerie commerciale,industrielle ou agricole (incluant machinerie lourde)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Industrie de lingerie, de vêtements de détente et de vêtements de nuit pour femmes et filles": cte.INDUSTRY,
      "Vente au détail d'équipements de plomberie, de chauffage, de ventilation, de climatisation et de foyer": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Autres industries de produits minéraux non métalliques": cte.INDUSTRY,
      "Entreprise d'excavation, de nivellement, de défrichage et installation de fosses septiques": cte.NON_HEATED,
      "Vente au détail, fournitures pour la maison et l'auto": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Industrie d'armoires, de placards de cuisine et de coiffeuses de salle de bains en bois": cte.INDUSTRY,
      "Terrain de sport (jeux et pistes pour compétitions et sport, gradins)": cte.SPORTS_LOCATION,
      "Vente au détail de piscines, de spas et leurs accessoires": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Service en santé mentale (cabinet) (comprend tous services professionnels, psychiatre,psychologue, psychanalyste)": cte.HEALTH_CARE,
      "Service de construction de routes, de rues et de ponts,de trottoirs et de pistes (entrepreneur général)": cte.NON_HEATED,
      "Vente en gros d'appareils électriques, de téléviseurs et de radios": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Vente au détail de motocyclettes, de motoneiges et de leurs accessoires": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Industrie du meuble rembourré résidentiel (rembourrage, service de réparation, voir 6423)": cte.INDUSTRY,
      "Vente au détail de jouets et d'articles de jeux": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Industrie du laminage, de l'étirage et de l'extrusion du cuivre et de ses alliages": cte.INDUSTRY,
      "Archives (incluant cinémathèque, vidéothèque)": cte.WAREHOUSE_REFRIGERATED,
      "Service de recherche, de développement et d'essais": cte.UNIVERSITY,
      "Industrie de tapis, carpettes et moquettes": cte.INDUSTRY,
      "Industrie du revêtement métallique, sur commande": cte.INDUSTRY,
      "Service de réparation et d'entretien de systèmes de plomberies,chauffage, ventilation et climatisation.(entrepreneur spécialisé)": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Salle de réunions, centre de conférence et congrès": cte.CONVENTION_CENTER,
      "Vente en gros d'autres médicaments, de produits chimiques et de produits connexes": cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD,
      "Vente au détail d'armoires de coiffeuses et de meubles d'appoint": cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD,
      "Industrie de chaudières, d'échangeurs de chaleur et de plaques métalliques": cte.INDUSTRY,
      "Industrie du clichage, de la composition de la reliure et de la lithographie": cte.INDUSTRY,
      "Service de construction non résidentielle, commerciale et institutionnelle (entrepreneur général)": cte.MEDIUM_OFFICE,
      "Centre d'entreposage de produits pétroliers (pétrole brut, gaz pétrole liquéfié, mazout domestique et autres produits raffinés)": cte.WAREHOUSE,
      "École à caractère familial (exploité par une personne physique dans sa résidence, moins de 15 élèves)": cte.PRIMARY_SCHOOL
    }

  @property
  def dictionary(self) -> dict:
    return self._dictionary
