"""
Dictionaries module for Alkis function to hub function
SPDX - License - Identifier: LGPL - 3.0 - or -later
Copyright © 2022 Concordia CERC group
Project Coder Guille Gutierrez Guillermo.GutierrezMorote@concordia.ca
"""


import hub.helpers.constants as cte

class AlkisFunctionToHubFunction:

  def __init__(self):
    self._dictionary = {"1000": cte.RESIDENTIAL,
                        "1010": "tenement",
                        "1020": "hostel",
                        "1030": "residential- and administration building",
                        "1040": "residential- and office building",
                        "1050": "residential- and business building",
                        "1060": "residential- and plant building",
                        "1070": "agrarian- and forestry building",
                        "1080": "residential- and commercial building",
                        "1090": "forester's lodge",
                        "1100": "holiday house",
                        "1110": "summer house",
                        "1120": "office building",
                        "1130": "credit institution",
                        "1140": "insurance",
                        "1150": "business building",
                        "1160": "department store",
                        "1170": "shopping centre",
                        "1180": "kiosk",
                        "1190": "pharmacy",
                        "1200": "pavilion",
                        "1210": cte.HOTEL,
                        "1220": "youth hostel",
                        "1230": "campsite building",
                        "1240": "restaurant",
                        "1250": "cantine",
                        "1260": "recreational site",
                        "1270": "function room",
                        "1280": "cinema",
                        "1290": "bowling alley",
                        "1300": "casino",
                        "1310": "industrial building",
                        "1320": "factory",
                        "1330": cte.WORKSHOP,
                        "1340": "petrol / gas station",
                        "1350": "washing plant",
                        "1360": "cold store",
                        "1370": "depot",
                        "1380": "building for research purposes",
                        "1390": "quarry",
                        "1400": "salt works",
                        "1410": "miscellaneous industrial building",
                        "1420": "mill",
                        "1430": "windmill",
                        "1440": "water mill",
                        "1450": "bucket elevator",
                        "1460": "weather station",
                        "1470": "traffic assets office",
                        "1480": "street maintenance",
                        "1490": "waiting hall",
                        "1500": "signal control box",
                        "1510": "engine shed",
                        "1520": "signal box or stop signal",
                        "1530": "plant building for air traffic",
                        "1540": "hangar",
                        "1550": "plant building for shipping",
                        "1560": "shipyard",
                        "1570": "dock",
                        "1580": "plant building for canal lock",
                        "1590": "boathouse",
                        "1600": "plant building for cablecar",
                        "1610": "multi-storey car park",
                        "1620": "parking level",
                        "1630": "garage",
                        "1640": "vehicle hall",
                        "1650": "underground garage",
                        "1660": "building for supply",
                        "1670": "waterworks",
                        "1680": "pump station",
                        "1690": "water basin",
                        "1700": "electric power station",
                        "1710": "transformer station",
                        "1720": "converter",
                        "1730": "reactor",
                        "1740": "turbine house",
                        "1750": "boiler house",
                        "1760": "building for telecommunications",
                        "1770": "gas works",
                        "1780": "heat plant",
                        "1790": "pumping station",
                        "1800": "building for disposal",
                        "1810": "building for effluent disposal",
                        "1820": "building for filter plant",
                        "1830": "toilet",
                        "1840": "rubbish bunker",
                        "1850": "building for rubbish incineration",
                        "1860": "building for rubbish disposal",
                        "1870": "building for agrarian and forestry",
                        "1880": "barn",
                        "1890": "stall",
                        "1900": "equestrian hall",
                        "1910": "alpine cabin",
                        "1920": "hunting lodge",
                        "1930": "arboretum",
                        "1940": "glass house",
                        "1950": "moveable glass house",
                        "1960": "public building",
                        "1970": "administration building",
                        "1980": "parliament",
                        "1990": "guildhall",
                        "2000": "post office",
                        "2010": "customs office",
                        "2020": "court",
                        "2030": "embassy or consulate",
                        "2040": "district administration",
                        "2050": "district government",
                        "2060": "tax office",
                        "2070": "building for education and research",
                        "2080": "comprehensive school",
                        "2090": "vocational school",
                        "2100": "college or university",
                        "2110": "research establishment",
                        "2120": "building for cultural purposes",
                        "2130": "castle",
                        "2140": "theatre or opera",
                        "2150": "concert building",
                        "2160": cte.MUSEUM,
                        "2170": "broadcasting building",
                        "2180": "activity building",
                        "2190": cte.LIBRARY,
                        "2200": "fort",
                        "2210": "religious building",
                        "2220": "church",
                        "2230": "synagogue",
                        "2240": "chapel",
                        "2250": "community center",
                        "2260": "place of worship",
                        "2270": "mosque",
                        "2280": "temple",
                        "2290": "convent",
                        "2300": "building for health care",
                        "2310": cte.HOSPITAL,
                        "2320": "healing centre or care home",
                        "2330": "health centre or outpatients clinic",
                        "2340": "building for social purposes",
                        "2350": "youth centre",
                        "2360": "seniors centre",
                        "2370": "homeless shelter",
                        "2380": "kindergarten or nursery",
                        "2390": "asylum seekers home",
                        "2400": cte.POLICE_STATION,
                        "2410": cte.FIRE_STATION,
                        "2420": "barracks",
                        "2430": "bunker",
                        "2440": cte.PENITENTIARY,
                        "2450": "cemetery building",
                        "2460": "funeral parlor",
                        "2470": "crematorium",
                        "2480": "train station",
                        "2490": "airport building",
                        "2500": "building for underground station",
                        "2510": "building for tramway",
                        "2520": "building for bus station",
                        "2530": "shipping terminal",
                        "2540": "building for recuperation purposes",
                        "2550": "building for sport purposes",
                        "2560": "sports hall",
                        "2570": "building for sports field",
                        "2580": "swimming baths",
                        "2590": "indoor swimming pool",
                        "2600": "sanatorium",
                        "2610": "zoo building",
                        "2620": cte.GREEN_HOUSE,
                        "2630": "botanical show house",
                        "2640": "bothy",
                        "2650": "tourist information centre",
                        "2700": "others",
                        }

  @property
  def dictionary(self) -> dict:
    return self._dictionary
